@@ -5,7 +5,7 @@ import streamlit.components.v1 as components
 import streamlit as st
 
 # Toggle this to False for local development
-_RELEASE = False
+_RELEASE = True
 
 if _RELEASE:
     root_dir = os.path.dirname(os.path.abspath(__file__))
